tests.test_utils module — pydevDAG 1.0 documentation

### Navigation

- index
- modules |
- previous |
- pydevDAG 1.0 documentation »
- tests »
- tests package »

# tests.test_utils module

## tests.test_utils

Tests utilities.

class `tests.test_utils.` `TestGraphUtils`

  Bases: `object`

  Test utilities that work over networkx graphs.

  `test_roots`()

    Verify that roots are really roots.

### Navigation

- index
- modules |
- previous |
- pydevDAG 1.0 documentation »
- tests »
- tests package »